@@ -31,9 +31,9 @@ class Command(BaseCommand):
     help = "Run e2e testserver."
     option_list = BaseCommand.option_list + (
         make_option('--addrport',type='str', dest='addrport',
-            help='port number or ipaddr:port'),
+                    help='port number or ipaddr:port'),
         make_option('--skip-test-db', '-t', action='store_true', dest='skip_test_db', default=False,
-            help='Tells Django to create an ephemeral db.'))
+                  help='Tells Django to create an ephemeral db.'))
 
     def handle(self, *fixture_labels, **options):
         from django.core.management import call_command
@@ -47,18 +47,45 @@ class Command(BaseCommand):
         addrport = (options.get('addrport', "127.0.0.1:8000"))
         skip_test_db = (options.get('skip_test_db'))
 
-        interactive = False
-        # Create a test database by default
-        if not skip_test_db:
-            connection.creation.create_test_db(verbosity=verbosity, autoclobber=not interactive, serialize=False)
-
-        # Import the fixture data into the database.
-        call_command('loaddata', *fixture_labels, **{'verbosity': verbosity})
-
+        settings.SKIP_TEST_DB = skip_test_db
         use_threading = connection.features.test_db_allows_multiple_connections
+
+        def load_data():
+            call_command('loaddata', *fixture_labels, **{'verbosity': verbosity})
+
+        def initialize_test_db():
+            params = {'verbosity': True,
+                          'autoclobber': False}
+            connection.creation.create_test_db(**params)
+            load_data()
+
+        def initializer():
+            if not settings.SKIP_TEST_DB:
+                initialize_test_db()
+
+            import importlib
+            import shelve
+            di = shelve.open('/tmp/drs_store')
+            for mock_module_string, value in di.iteritems():
+
+                imported_mock = importlib.import_module(mock_module_string)
+
+                setattr(imported_mock.to_mock,
+                        imported_mock.to_mock_attr,
+                        imported_mock.mock
+                        )
+            di.close()
+
+        settings.MOCKED_MODULES = set()
+
+        if settings.SKIP_TEST_DB:
+            load_data()
+
+        settings.E2E_RELOAD_INITIALIZER = initializer
+
         call_command(
-            'runserver',
+            'runserver_patched',
             addrport=addrport,
-            use_reloader=False,
+            use_reloader=True,
             use_threading=use_threading
-        )
+            )
